pub fn walk(
request: &GenerateRequestView<'_>,
type_map: &mut TypeMap,
) -> Result<CatalogInfo, Error>Expand description
Walk the catalog, register discovered custom types into type_map, return info for codegen.
pub fn walk(
request: &GenerateRequestView<'_>,
type_map: &mut TypeMap,
) -> Result<CatalogInfo, Error>Walk the catalog, register discovered custom types into type_map, return info for codegen.