pub struct ColumnView<'a> {Show 17 fields
pub name: &'a str,
pub not_null: bool,
pub is_array: bool,
pub comment: &'a str,
pub length: i32,
pub is_named_param: bool,
pub is_func_call: bool,
pub scope: &'a str,
pub table: MessageFieldView<IdentifierView<'a>>,
pub table_alias: &'a str,
pub type: MessageFieldView<IdentifierView<'a>>,
pub is_sqlc_slice: bool,
pub embed_table: MessageFieldView<IdentifierView<'a>>,
pub original_name: &'a str,
pub unsigned: bool,
pub array_dims: i32,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
name: &'a strField 1: name
not_null: boolField 3: not_null
is_array: boolField 4: is_array
comment: &'a strField 5: comment
length: i32Field 6: length
is_named_param: boolField 7: is_named_param
is_func_call: boolField 8: is_func_call
scope: &'a strXXX: Figure out what PostgreSQL calls foo.id
Field 9: scope
table: MessageFieldView<IdentifierView<'a>>Field 10: table
table_alias: &'a strField 11: table_alias
type: MessageFieldView<IdentifierView<'a>>Field 12: type
is_sqlc_slice: boolField 13: is_sqlc_slice
embed_table: MessageFieldView<IdentifierView<'a>>Field 14: embed_table
original_name: &'a strField 15: original_name
unsigned: boolField 16: unsigned
array_dims: i32Field 17: array_dims
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for ColumnView<'a>
impl<'a> Clone for ColumnView<'a>
Sourcefn clone(&self) -> ColumnView<'a>
fn clone(&self) -> ColumnView<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for ColumnView<'a>
impl<'a> Debug for ColumnView<'a>
Sourceimpl<'a> Default for ColumnView<'a>
impl<'a> Default for ColumnView<'a>
Sourcefn default() -> ColumnView<'a>
fn default() -> ColumnView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for ColumnView<'static>
impl DefaultViewInstance for ColumnView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for ColumnView<'a>
impl<'a> HasDefaultViewInstance for ColumnView<'a>
Sourcetype Static = ColumnView<'static>
type Static = ColumnView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for ColumnView<'a>
impl<'a> MessageView<'a> for ColumnView<'a>
Sourcefn to_owned_message(&self) -> Column
fn to_owned_message(&self) -> Column
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more