pub struct EnumView<'a> {
pub name: &'a str,
pub vals: RepeatedView<'a, &'a str>,
pub comment: &'a str,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
name: &'a strField 1: name
vals: RepeatedView<'a, &'a str>Field 2: vals
comment: &'a strField 3: comment
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for EnumView<'static>
impl DefaultViewInstance for EnumView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for EnumView<'a>
impl<'a> HasDefaultViewInstance for EnumView<'a>
Sourceimpl<'a> MessageView<'a> for EnumView<'a>
impl<'a> MessageView<'a> for EnumView<'a>
Sourcefn to_owned_message(&self) -> Enum
fn to_owned_message(&self) -> Enum
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more