pub struct IdentifierView<'a> {
pub catalog: &'a str,
pub schema: &'a str,
pub name: &'a str,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
catalog: &'a strField 1: catalog
schema: &'a strField 2: schema
name: &'a strField 3: name
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for IdentifierView<'a>
impl<'a> Clone for IdentifierView<'a>
Sourcefn clone(&self) -> IdentifierView<'a>
fn clone(&self) -> IdentifierView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for IdentifierView<'a>
impl<'a> Debug for IdentifierView<'a>
Sourceimpl<'a> Default for IdentifierView<'a>
impl<'a> Default for IdentifierView<'a>
Sourcefn default() -> IdentifierView<'a>
fn default() -> IdentifierView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for IdentifierView<'static>
impl DefaultViewInstance for IdentifierView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for IdentifierView<'a>
impl<'a> HasDefaultViewInstance for IdentifierView<'a>
Sourcetype Static = IdentifierView<'static>
type Static = IdentifierView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for IdentifierView<'a>
impl<'a> MessageView<'a> for IdentifierView<'a>
Sourcefn to_owned_message(&self) -> Identifier
fn to_owned_message(&self) -> Identifier
Convert this view to the owned message type.
Sourcetype Owned = Identifier
type Owned = Identifier
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more