pub struct QueryView<'a> {
pub text: &'a str,
pub name: &'a str,
pub cmd: &'a str,
pub columns: RepeatedView<'a, ColumnView<'a>>,
pub params: RepeatedView<'a, ParameterView<'a>>,
pub comments: RepeatedView<'a, &'a str>,
pub filename: &'a str,
pub insert_into_table: MessageFieldView<IdentifierView<'a>>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
text: &'a strField 1: text
name: &'a strField 2: name
cmd: &'a strField 3: cmd
columns: RepeatedView<'a, ColumnView<'a>>Field 4: columns
params: RepeatedView<'a, ParameterView<'a>>Field 5: params
comments: RepeatedView<'a, &'a str>Field 6: comments
filename: &'a strField 7: filename
insert_into_table: MessageFieldView<IdentifierView<'a>>Field 8: insert_into_table
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for QueryView<'static>
impl DefaultViewInstance for QueryView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for QueryView<'a>
impl<'a> HasDefaultViewInstance for QueryView<'a>
Sourceimpl<'a> MessageView<'a> for QueryView<'a>
impl<'a> MessageView<'a> for QueryView<'a>
Sourcefn to_owned_message(&self) -> Query
fn to_owned_message(&self) -> Query
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more